@@ -188,6 +188,7 @@ impl Database
     }
 
     /// Return a list of all unique tags found in the database
+    ///
     /// Return an Error if the database was unreachable
     pub fn list_tags(&self) -> Result<Vec<String>, Error>
     {
@@ -206,6 +207,24 @@ impl Database
         Ok(results)
     }
 
+    /// Return a list of all unique project names found in the database
+    ///
+    /// Return an Error if the database was unreachable
+    pub fn list_projects(&self) -> Result<Vec<String>, Error>
+    {
+        let mut stmt = self.conn.prepare("SELECT project FROM zettelkasten")?;
+        let mut rows = stmt.query([])?;
+
+        let mut results: Vec<String> = Vec::new();
+        while let Some(row) = rows.next()? {
+            let project: String = row.get(0)?;
+            results.push(project);
+        }
+        results.par_sort();
+        results.dedup();
+        Ok(results)
+    }
+
     /// Search in the database for the Zettel whose `links` property includes `pattern`, and
     /// return them
     /// Return an Error if the database was unreachable
