@@ -35,7 +35,7 @@ fn find_tags(contents: &str) -> Vec<String>
 pub struct Zettel
 {
     pub title: String,
-    pub inbox: bool,
+    pub project: String,
     pub links: Vec<String>,
     pub tags: Vec<String>,
 }
@@ -43,30 +43,31 @@ pub struct Zettel
 impl Zettel
 {
     /// Create a Zettel with specified `title`
-    pub fn new(title: &str, inbox: bool) -> Self
+    pub fn new(title: &str, project: &str) -> Self
     {
         Zettel
         {
             title: title.to_string(),
-            inbox,
+            project: project.to_string(),
             links: vec![],
             tags: vec![],
         }
     }
 
     /// Create a Zettel from a file, provided a path
-    pub fn from_file(path: &str) -> Self
+    pub fn from_file(cfg: &ConfigOptions, path: &str) -> Self
     {
         let title = basename(&replace_extension(path, ""));
         let contents = file_to_string(path);
 
-        let mut is_inbox = false;
-        let pieces: Vec<_> = path.split('/').collect();
-        if pieces[pieces.len() - 2] == "inbox" {
-            is_inbox = true;
-        }
+        let project = if dirname(path) == cfg.zettelkasten {
+            "".to_string()
+        } else {
+            let segments: Vec<&str> = path.split('/').collect();
+            segments[segments.len() - 2].to_string()
+        };
 
-        let mut zettel = Zettel::new(&title, is_inbox);
+        let mut zettel = Zettel::new(&title, &project);
         zettel.links = find_links(&contents);
         zettel.tags = find_tags(&contents);
         zettel
@@ -76,6 +77,7 @@ impl Zettel
     /// a blank file.
     pub fn create(&self, cfg: &ConfigOptions)
     {
+        mkdir(&format!("{}/{}", &cfg.zettelkasten, &self.project));
         if file_exists(&cfg.template) {
             let template_contents = file_to_string(&cfg.template);
             let new_zettel_contents = self.replace_template_placeholders(&template_contents);
@@ -95,12 +97,7 @@ impl Zettel
     /// ```
     pub fn filename(&self, cfg: &ConfigOptions) -> String
     {
-        let dir;
-        if self.inbox {
-            dir = format!("{}/inbox", cfg.zettelkasten);
-        } else {
-            dir = cfg.zettelkasten.clone();
-        }
+        let dir = format!("{}/{}", cfg.zettelkasten, &self.project);
         format!("{}/{}.md", dir, &self.title)
     }
 
